emoticons = {
":)": "Smile.png",
":-)": "Smile.png",
":D": "D.png",
";)": "Wink.png",
";o)": "Wink.png",
";-)": "Wink.png",
":(": "Sad.png",
":-(": "Sad.png",
":sadnoir:": "SadNoir.png",
":'(": "Ohill.gif",
":arf:": "Arf.png",
":arg:": "Arg.png",
":/": "Erf.png",
":-/": "Erf.png",
":|": "No.png",
":-|": "No.png",
":p": "Tongue.png",
":P": "Tongue.png",
":-p": "Tongue.png",
":-P": "Tongue.png",
":o": "O.png",
":-o": "O.png",
":??:": "Confused.png",
":sweat:": "Sweat.png",
":mmmfff:": "Mmmfff.png",
":sol:": "Sol.png",
":dawa:": "Dawa.png",
":dawak:": "Dawak.png",
":dawahello:": "DawaHello.gif",
":dawanon:": "DawaNon.gif",
":dawanoel:": "DawaNoel.png",
":god:": "God.png",
":love:": "Love.gif",
":boidleau:": "Boidleau.png",
":chacal_one333:": "Chacal_One333.png",
":autobot:": "Autobot.png",
":cupra:": "Cupra.png",
":ddr555:": "Ddr555.png",
":fou:": "Fou.png",
":fuck:": "Fuck.png",
":kneu:": "Kneu.png",
":mlc:": "Mlc.png",
":mlc2:": "Mlc.png",
":ouch:": "Ouch.png",
":pingouino:": "Pingouino.png",
":kiki:": "Kiki.png",
":huit:": "Huit.png",
":neuf:": "Neuf.png",
":tinostar:": "Tinostar.png",
":haha:": "Haha.png",
":hahaguy:": "Hahaguy.png",
":petrus75:": "Petrus.png",
":shay:": "Shay.png",
"\o/": "Shay.png",
":ciler:": "Ciler.png",
":tt:": "TT.png",
":vomi:": "Vomi.gif",
":drapal:": "Drapal.png",
":-1:": "-1.png",
":+1:": "+1.png",
":wedgeant:": "+1.png",
":ban:": "Ban.png",
":boulay:": "Boulay.png",
":thalis:": "Thalis.png",
":afrojojo:": "Afrojojo.png",
":pouah:": "Pouah.png",
":nico54:": "Nico54.png",
":yvele:": "Yvele.png",
":joce:": "Joce.png",
":popcorn:": "Popcorn.png",
":x": "Shut.png",
":neriki:": "Neriki.png",
":cry:": "Cry.gif",
":whistle:": "Whistle.gif",
":heink:": "Heink.gif",
":jap:": "Jap.gif",
":sleep:": "Sleep.gif",
":pt1cable:": "Pt1Cable.gif",
":arn0:": "Arn0.gif",
":spamafote:": "Spamafote.gif",
":eonwe:": "Eonwe.gif",
":delight:": "Delight.gif",
":violon:": "Violon.gif",
":zebra33:": "Zebra.gif",
":discobeck:": "Discobeck.gif",
":bounce:": "Bounce.gif",
":merdocu:": "Merdocu.gif",
":zoubi:": "Zoubi.gif",
":wam:": "Wam.gif",
":hebe:": "Wam.gif",
":branlette:": "Branlette.gif",
":elmoricq:": "Elmoricq.gif",
":roi:": "Roi.gif",
":kahn21:": "Kahn21.gif",
":adodonicoco:": "Adodonicoco.gif",
":totoz:": "Totoz.gif",
":alph-one:": "Totoz.gif",
":prodigy:": "Prodigy.png",
":makokotte:": "Makokotte.gif",
":simchevelu:": "Simchevelu.gif",
":bernadette:": "Bernadette.png",
":sisicaivrai:": "Sisicaivrai.gif",
":perchut2:": "Perchut2.gif",
":obawi:": "Obawi.gif",
":kukron:": "Kukron.gif",
":skyzor:": "Skyzor.gif",
":atsuko:": "Atsuko.gif",
":zeusy:" : "Zeusy.png",
":dawacube:" : "DawaCube.gif",
":lol:": "Lol.gif",
":rofl:": "Rofl.gif",
":rofl2:": "Rofl2.gif",
":toad666:" : "Toad666.gif",
":sarcastic:": "Sarcastic.gif",
":aloy:": "Aloy.png",
":debarquement:": "Debarquement.png",
":grilled:": "Grilled.gif",
":hello:": "Hello.gif",
":hurle:": "Hurle.png",
":prozac:": "Prozac.png",
":daria:": "Daria.png",
":bresse:": "Bresse.png",
":gnoufou:": "Gnoufou.gif",
":volta:": "Volta.png",
":chaleur intempestive:": "Chaleur_Intempestive.gif",
":datoune:": "Chaleur_Intempestive.gif",
":grisemine:": "Grisemine.png",
":sherlock:": "Sherlock.png",
":ndi76:": "Ndi76.gif",
":blackmetal:": "Blackmetal.png",
":cawa:": "Cawa.gif",
":klem:": "Klem.png",
":ocube:": "OCube.png",
":picole:": "Picole.gif",
":rhetorie du chaos:": "Rhetorie_Du_Chaos.png",
":sadistyk:": "Sadistyk.png",
":tang:": "Tang.gif",
":tristanf:": "TristanF.gif",
":itm:": "ITM.png",
":non:": "Non.gif",
":gratgrat:": "Gratgrat.gif",
":phenos:": "Phenos.png",
":cosmoschtroumpf:": "Cosmoschtroumpf.png",
":tibo2002:": "Tibo2002.png",
":draculax:": "Draculax.png",
":calin:": "Calin.gif",
":briseparpaing:": "BriseParpaing.gif",
":blessure:": "Blessure.png",
":golden blessure:": "Golden_Blessure.png",
":jaffax:": "Jaffax.png",
":tarlooze:": "Tarlooze.gif",
":jalouse:": "Jalouse.png",
":classe++:": "Jalouse.png",
":hfrbaxter:": "HFRBaxter.gif",
":ninipc:": "NiniPC.gif",
":sinking:": "Sinking.png",
":nerd:": "Sinking.png",
":xxantoinexx:": "Sinking.png",
":sarko:": "Sarko.png",
":delarue:": "Delarue.png",
":delarue2:": "Delarue2.png",
":delarue3:": "Delarue3.png",
":delarue4:": "Delarue4.png",
":delarue5:": "Delarue5.png",
":delarue6:": "Delarue6.png",
":wahoo:": "Wahoo.gif",
":kryten:": "Kryten.png",
":dtc:": "DTC.png",
}
